@@ -1,9 +1,8 @@
-#undef BIND_MIME
 #undef ENABLE_NLS
+#undef GTK_ENABLE_BROKEN
 #undef HAVE_CATGETS
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_LIBSM
 #undef HAVE_STPCPY
-#undef JW_PRESENT
-#undef SCROLLKEEPER_PRESENT
+#undef GETTEXT_PACKAGE
