@@ -1,6 +1,6 @@
 /*
- * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
- *			Gediminas Paulauskas <menesis@gtranslator.org>
+ * (C) 2001-2002 	Fatih Demir <kabalak@kabalak.net>
+ *			Gediminas Paulauskas <menesis@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,11 +40,6 @@ enum {
 	ACT_REVERT,
 	ACT_CLOSE,
 	/***********************/
-#ifdef UTF8_CODE
-	ACT_IMPORT_UTF8,
-	ACT_EXPORT_UTF8,
-	/***********************/
-#endif
 	ACT_UNDO,
 	ACT_CUT,
 	ACT_COPY,
