@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,10 @@
 #ifndef GTR_DEFINES
 #define GTR_DEFINES 1
 
-#define BUILD_STRING	"1.1.5 -- 2004-05-28 21:37:53"
-#define BUILD_VERSIONS	"2.5.0 / 2.5.0 / 2.6.1.1 / 2.6.10"
-#define SCHEMESDIR	"/usr/share/gtranslator/colorschemes"
-#define SCRIPTSDIR	"/usr/share/gtranslator/scripts"
-#define WINDOW_ICON	"/usr/share/pixmaps/gtranslator.png"
+#define BUILD_STRING	"1.1.6 -- 2005-02-06 12:56:02"
+#define BUILD_VERSIONS	"2.6.1 / 2.6.1 / 2.9.1 / 2.6.17"
+#define SCHEMESDIR	"/usr/local/share/gtranslator/colorschemes"
+#define SCRIPTSDIR	"/usr/local/share/gtranslator/scripts"
+#define WINDOW_ICON	"/usr/local/share/pixmaps/gtranslator.png"
 
 #endif
