@@ -1,9 +1,9 @@
 /*
- * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
- *			Gediminas Paulauskas <menesis@gtranslator.org>
- *			Peeter Vois <peeter@gtranslator.org>
- *			Thomas Ziehmer <thomas@gtranslator.org>
- *			Ross Golder <ross@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@kabalak.net>
+ *			Gediminas Paulauskas <menesis@kabalak.net>
+ *			Peeter Vois <peeter@kabalak.net>
+ *			Thomas Ziehmer <thomas@kabalak.net>
+ *			Ross Golder <ross@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,9 +32,6 @@
 #include "dialogs.h"
 #include "dnd.h"
 #include "find.h"
-#ifdef NOT_PORTED
-# include "gtkspell.h"
-#endif
 #include "gui.h"
 #include "header_stuff.h"
 #include "history.h"
@@ -46,7 +43,6 @@
 #include "prefs.h"
 #include "runtime-config.h"
 #include "stylistics.h"
-#include "syntax.h"
 #include "translator.h"
 #include "undo.h"
 #include "utils.h"
@@ -68,6 +64,7 @@
 #include <libgnomeui/gnome-popup-menu.h>
 
 #include <libgnomevfs/gnome-vfs-init.h>
+#include <gtkspell/gtkspell.h>
 
 /*
  * Global external variables
@@ -80,10 +77,6 @@ GtkWidget *gtranslator_application_bar;
 
 GtkWidget *content_pane;
 GtkWidget *table_pane;
-#ifdef NOT_PORTED
-guint text_box_insert_text_signal_id;
-guint text_box_delete_text_signal_id;
-#endif
 guint trans_box_insert_text_signal_id;
 guint trans_box_delete_text_signal_id;
 
@@ -267,21 +260,13 @@ void gtranslator_create_main_window(void)
 
 	gtranslator_history_show();
 
-	/*
-	 * Set up our special styles for the text boxes.
-	 */
-	//	gtranslator_set_style(GTK_WIDGET(text_box), 0);
-	//gtranslator_set_style(GTK_WIDGET(trans_box), 1);
-	/*
-	 *  Initialize highlighting
-	 */
-	 gtranslator_syntax_init(trans_box);
-	 gtranslator_syntax_init(text_box);
 	/*
 	 * The callbacks list
 	 */
-	g_signal_connect(G_OBJECT(gtranslator_application), "delete_event",
-			 G_CALLBACK(gtranslator_quit), NULL);
+	g_signal_connect(G_OBJECT(gtranslator_application),
+			"delete_event",
+			 G_CALLBACK(gtranslator_application_delete_event_cb),
+			 NULL);
 
 	g_signal_connect(G_OBJECT(extra_content_view->edit_button), "clicked",
 			 G_CALLBACK(gtranslator_edit_comment_dialog), NULL);
@@ -291,16 +276,6 @@ void gtranslator_create_main_window(void)
 	g_signal_connect_after(G_OBJECT(trans_box), "selection-get",
 			 G_CALLBACK(selection_get_handler), NULL);
 
-#ifdef NOT_PORTED
-	text_box_insert_text_signal_id = g_signal_connect(
-		G_OBJECT(gtk_text_view_get_buffer(text_box)), 
-		"insert-text",
-		G_CALLBACK(insert_text_handler), NULL);
-	text_box_delete_text_signal_id = g_signal_connect(
-		G_OBJECT(gtk_text_view_get_buffer(text_box)),
-		"delete-range",
-		G_CALLBACK(delete_text_handler), NULL);
-#endif
 	trans_box_insert_text_signal_id = g_signal_connect(
 		G_OBJECT(gtk_text_view_get_buffer(trans_box)), 
 		"insert-text",
@@ -354,11 +329,34 @@ void delete_text_handler(GtkTextBuffer *textbuf, GtkTextIter *start,
 	g_signal_stop_emission_by_name (G_OBJECT (textbuf), "delete-text");
 }
 
+/*
+ * Callback called when the user closes the main window
+ *
+ * This callback is connected to the delete-event signal on the
+ * gtranslator GnomeApp (ie the main window) and should be called when the user
+ * closes the main window.
+ * It returns true to stop other handlers from being invoked for the event.
+ */
+gboolean gtranslator_application_delete_event_cb(GtkWidget  * widget,
+						 GdkEvent  * event,
+						 gpointer user_data)
+{
+	gtranslator_quit();
+	return TRUE;
+}
+
+/*
+ * Callback called when the user uses the quit command (^Q or Quit in the menu)
+ */
+void gtranslator_menu_quit_cb(void  * data)
+{
+	gtranslator_quit();
+}
+
 /*
  * The own quit-code
  */
-void gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
-			     gpointer useless)
+void gtranslator_quit()
 {
 	/*
 	 * If file was changed, but user pressed Cancel, don't quit
@@ -736,8 +734,9 @@ void gtranslator_translation_changed(GtkWidget  *buffer, gpointer useless)
 		if ((GtrPreferences.unmark_fuzzy) 
 		     && (msg->status & GTR_MSG_STATUS_FUZZY))
 		{
-		     	gtranslator_message_status_set_fuzzy(msg, FALSE);
-			po->fuzzy--;
+			gtranslator_message_status_set_fuzzy(msg, FALSE);
+			/* the callback on this GtkCheckMenuItem will be called
+			 * and the fuzzy count will be correctly decreased */
 			gtk_check_menu_item_set_active(
 				GTK_CHECK_MENU_ITEM(the_edit_menu[19].widget),
 				FALSE
@@ -777,9 +776,7 @@ void insert_text_handler (GtkTextBuffer *textbuffer, GtkTextIter *pos,
 		}
 	}
 
-#ifdef NOT_PORTED
-	gtranslator_insert_highlighted(textbuffer, pos, result, length, data);
-#endif
+//	gtranslator_insert_text(textbuffer, pos, result, length, data);
 	g_signal_handler_block(textbuffer, trans_box_insert_text_signal_id);
 	gtk_text_buffer_insert(textbuffer, pos, result, length);
 	g_signal_handler_unblock(textbuffer, trans_box_insert_text_signal_id);
