@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@kabalak.net>
  * 			GNOME I18N List <gnome-i18n@gnome.org>
  * 			Guntupalli Karunakar <karunakar@freedomink.org>
  *
@@ -54,8 +54,8 @@ GtrLanguage languages[] = {
 	 "linux-eu@chanae.alphanet.ch", "8bit"
 	},
 	{
-	 N_("Belorussian"), "be", "windows-1251",
-	 "", "8bit"
+	 N_("Belarusian"), "be", "UTF-8",
+	 "i18n@mova.org", "8bit"
 	},
         {
          N_("Bengali"), "bn", "UTF-8",
@@ -149,6 +149,10 @@ GtrLanguage languages[] = {
 	 N_("Gujarati"), "gu", "UTF-8",
 	 "indlinux-gujarati@lists.sourceforge.net", "8bit"
 	},
+	{
+	 N_("Hebrew"), "he", "UTF-8",
+	 "", "8bit"
+	},
 	{
 	 N_("Hindi"), "hi", "UTF-8",
 	 "indlinux-hindi-gnome@lists.sourceforge.net", "8bit"
@@ -167,7 +171,7 @@ GtrLanguage languages[] = {
 	},
 	{
 	 N_("Italian"), "it", "iso-8859-1",
-	 "it@li.org", "8bit"
+	 "tp@lists.linux.it", "8bit"
 	},
 	{
 	 N_("Irish"), "ga", "iso-8859-1",
@@ -226,8 +230,8 @@ GtrLanguage languages[] = {
 	 "pt@li.org", "8bit"
 	},
 	{
-	 N_("Portuguese/Brazil"), "pt_BR", "iso-8859-1",
-	 "", "8bit"
+	 N_("Portuguese/Brazil"), "pt_BR", "UTF-8",
+	 "gnome-l10n-br@listas.cipsga.org.br", "8bit"
 	},
 	{
 	 N_("Romanian"), "ro", "iso-8859-2",
@@ -269,6 +273,10 @@ GtrLanguage languages[] = {
 	 N_("Swedish"), "sv", "iso-8859-1",
 	 "sv@li.org", "8bit"
 	},
+	{
+	 N_("Tagalog"), "tl", "UTF-8",
+	 "debian-tl@banwa.upm.edu.ph", "8bit"
+	},
 	{
 	 N_("Tamil"), "ta", "tscii",
 	 "", "8bit"
@@ -279,7 +287,7 @@ GtrLanguage languages[] = {
 	},
 	{
 	 N_("Thai"), "th", "tis-620",
-	 "", "8bit"
+	 "l10n@opentle.org", "8bit"
 	},
 	{
 	 N_("Turkish"), "tr", "ISO-8859-9",
