@@ -1,8 +1,8 @@
 /*
- * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
- * 			Gediminas Paulauskas <menesis@gtranslator.org>
- * 			Thomas Ziehmer <thomas@gtranslator.org>
- * 			Ross Golder <ross@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@kabalak.net>
+ * 			Gediminas Paulauskas <menesis@kabalak.net>
+ * 			Thomas Ziehmer <thomas@kabalak.net>
+ * 			Ross Golder <ross@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,9 +27,6 @@
 #include "actions.h"
 #include "comment.h"
 #include "dialogs.h"
-#ifdef NOT_PORTED
-# include "gtkspell.h"
-#endif
 #include "gui.h"
 #include "learn.h"
 #include "menus.h"
@@ -37,24 +34,22 @@
 #include "messages-table.h"
 #include "parse.h"
 #include "prefs.h"
-#include "syntax.h"
 #include "undo.h"
-#ifdef UTF8_CODE
-# include "utf8.h"
-#endif
 #include "utils.h"
 #include "utils_gui.h"
 
 #include <string.h>
 #include <regex.h>
 #include <gtk/gtk.h>
-
+#include <gtkspell/gtkspell.h>
 #include <libgnomeui/gnome-app.h>
 #include <libgnomeui/gnome-app-util.h>
 
 static gboolean is_fuzzy(GList *msg, gpointer useless);
 static gboolean is_untranslated(GList *msg, gpointer useless);
 
+GtkSpell *gtrans_spell = NULL;
+
 /*
  * The callback handling the editing of the plural forms and the correcponding tree handle.
  */
@@ -205,9 +200,7 @@ static void plural_forms_edited(GtkCellRendererText *crtext, gchar *path, gchar
  */
 void gtranslator_message_show(GtrMsg *msg)
 {
-#ifdef NOT_PORTED
-	gchar *ispell_command[5];
-#endif
+	GtkTextBuffer *buf;
 
 	if(!file_opened)
 	{
@@ -240,22 +233,26 @@ void gtranslator_message_show(GtrMsg *msg)
 		g_return_if_fail(msg->msgid!=NULL);
 		
 		temp = gtranslator_utils_invert_dot(msg->msgid);
-		gtranslator_insert_text(text_box, temp);
+		buf =  gtk_text_view_get_buffer(text_box);
+		gtk_text_buffer_set_text(buf, temp, -1);
 		
 		GTR_FREE(temp);
 
 		if (msg->msgstr) {
 			temp = gtranslator_utils_invert_dot(msg->msgstr);
 			
-			gtranslator_insert_text(trans_box, temp);
+			buf = gtk_text_view_get_buffer(trans_box);
+			gtk_text_buffer_set_text(buf, temp, -1);
 			
 			GTR_FREE(temp);
 		}
 	} else {
-		gtranslator_insert_text(text_box, msg->msgid);
-		gtranslator_insert_text(trans_box, msg->msgstr);
+		buf = gtk_text_view_get_buffer(text_box);
+		gtk_text_buffer_set_text(buf, msg->msgid, -1);
+		buf = gtk_text_view_get_buffer(trans_box);
+		gtk_text_buffer_set_text(buf, msg->msgstr, -1);
 	}
-#ifdef NOT_PORTED	
+
 	/*
 	 * Use instant spell checking via gtkspell only if the corresponding
 	 *  setting in the preferences is set.
@@ -265,36 +262,23 @@ void gtranslator_message_show(GtrMsg *msg)
 		/*
 		 * Start up gtkspell if not already done.
 		 */ 
-		if(!gtkspell_running())
-		{
-			ispell_command[0]="ispell";
-			ispell_command[1]="-a";
-			
-			/*
-			 * Should we use special dictionary settings?
-			 */ 
-			if(GtrPreferences.use_own_dict && GtrPreferences.dictionary)
-			{
-				ispell_command[2]="-d";
-				ispell_command[3]=g_strdup_printf("%s",
-					GtrPreferences.dictionary);
-				ispell_command[4]=NULL;
-			} else {
-				ispell_command[2]=NULL;
-			}
+		GError *error = NULL;
+		char *errortext = NULL;
 		
-			/*
-			 * Start the gtkspell process.
-			 */ 
-			gtkspell_start(NULL, ispell_command);
-		}
-
-		/*
-		 * Attach it to the translation box for instant spell checking.
-		 */ 
-		gtkspell_attach(GTK_TEXT(trans_box));
+		if (gtrans_spell == NULL && trans_box != NULL) {
+		    gtrans_spell = gtkspell_new_attach(trans_box, NULL, &error);
+		    if (gtrans_spell == NULL) {
+			g_print(_("gtkspell error: %s\n"), error->message);
+			errortext = g_strdup_printf(_("GtkSpell was unable to initialize.\n %s"), error->message);
+			g_error_free(error);
+		    }
+		} 		
+	} else {
+	    if (gtrans_spell != NULL) {
+		gtkspell_detach(gtrans_spell);
+		gtrans_spell = NULL;
+	    }
 	}
-#endif //NOT_PORTED
 
 	gtk_check_menu_item_set_active(
 		GTK_CHECK_MENU_ITEM(the_edit_menu[19].widget),
@@ -421,23 +405,6 @@ void gtranslator_message_update(void)
 
 		GTR_FREE(msg->msgstr);
 
-#ifdef UTF8_CODE
-		if(po->utf8)
-		{
-			msg->msgstr=gtranslator_utf8_get_gtk_text_as_utf8_string(GTK_WIDGET(trans_box));
-		}
-		else
-		{
-			msg->msgstr=gtk_editable_get_chars(
-				GTK_EDITABLE(trans_box), 0, len);
-		}
-		*/
-		// XXX we always work with utf-8
-		// YYY that's why I'm preparing to carve out all
-		//     the utf-8 stuff except and make sure there
-		//     are g_converts on load/save (for non-utf8
-		//     users).
-#endif
 
 		msg->msgstr = gtk_text_buffer_get_text(gtk_text_view_get_buffer(trans_box), &start, &end, FALSE);
 		
@@ -531,7 +498,7 @@ void gtranslator_message_go_to(GList * to_go)
 	GtkTextMark *mark = NULL;
  
 	g_return_if_fail (to_go!=NULL);
-
+	
 	gtranslator_message_update();
 	
 	if (pos == 0)
