@@ -1,7 +1,7 @@
 /*
- * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
- *			Gediminas Paulauskas <menesis@gtranslator.org>
- *			Ross Golder <ross@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@kabalak.net>
+ *			Gediminas Paulauskas <menesis@kabalak.net>
+ *			Ross Golder <ross@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,9 +33,6 @@
 #include "actions.h"
 #include "comment.h"
 #include "dialogs.h"
-#ifdef NOT_PORTED
-# include "gtkspell.h"
-#endif
 #include "gui.h"
 #include "history.h"
 #include "message.h"
@@ -48,15 +45,13 @@
 #include "save.h"
 #include "translator.h"
 #include "undo.h"
-#ifdef UTF8_CODE
-# include "utf8.h"
-#endif
 #include "utils.h"
 #include "utils_gui.h"
 
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtklabel.h>
+#include <gtkspell/gtkspell.h>
 
 #include <libgnomeui/gnome-appbar.h>
 #include <libgnomeui/gnome-app-util.h>
@@ -231,32 +226,6 @@ GtrPo *gtranslator_parse(const gchar *filename)
 	po->file_changed = FALSE;
 	po->length = g_list_length(po->messages);
 
-#ifdef UTF8_CODE
-	/*
-	 * Set the utf8 field of the GtrPo to TRUE if we are editing an UTF-8 
-	 *  encoded file.
-	 */
-	if(gtranslator_utf8_po_file_is_utf8(po))
-	{
-		po->utf8=TRUE;
-	}
-	else
-	{
-		po->utf8=FALSE;
-	}
-
-	po->locale_charset=gtranslator_utils_get_locale_charset(po);
-	
-	/* FIXME: converting the messages to UTF8 there since I don't
-	   know the parsing code, and I don't feel like figuring it out
-	   so I temporarily put this here to ensure all the strings are 
-	   properly encoded. Please fix it...
-	*/
-	if (po->utf8 == FALSE) {
-		gtranslator_utf8_convert_po_to_utf8(po);
-	}
-#endif
-
 	/*
 	 * Set the current message to the first message.
 	 */
@@ -1075,23 +1044,32 @@ void gtranslator_save_current_file_dialog(GtkWidget * widget, gpointer useless)
  */
 void gtranslator_po_free(GtrPo *po)
 {
+	/* in this function, we force clearing so we will notice if we reuse
+	 * any var mistakingly */
+
 	g_return_if_fail(po!=NULL);
 
-	if (po->messages) 
+	if (po->messages)
 	{
 		g_list_foreach(po->messages, gtranslator_message_free, NULL);
 		g_list_free(po->messages);
+		po->messages = NULL;
 	}
 	
 	if (po->header)
 	{
 		gtranslator_header_free(po->header);
+		po->header = NULL;
 	}
 	
 	GTR_FREE(po->locale_charset);
+	po->locale_charset = NULL;
 	GTR_FREE(po->filename);
+	po->filename = NULL;
 	GTR_FREE(po->obsolete);
+	po->obsolete = NULL;
 	GTR_FREE(po);
+	po = NULL;
 }
 
 void gtranslator_file_close(GtkWidget * widget, gpointer useless)
@@ -1118,16 +1096,6 @@ void gtranslator_file_close(GtkWidget * widget, gpointer useless)
 		gtranslator_messages_table_clear();
 	}
 
-#ifdef NOT_PORTED
-	/*
-	 * Stop gtkspell.
-	 */ 
-	if(GtrPreferences.instant_spell_check && gtkspell_running())
-	{
-		gtkspell_stop();
-	}
-#endif /* NOT_PORTED */	
-
 	gtranslator_text_boxes_clean();
 	gtk_label_set_text(GTK_LABEL(extra_content_view->comment), "");
 	gtk_widget_set_sensitive(GTK_WIDGET(extra_content_view->edit_button), FALSE);
